# Contributing to `aibs-informatics-test-resources`

Contributions are welcome, and they are greatly appreciated! Every little bit helps, and credit will always be given.

## Types of Contributions

### Reporting Bugs

Report bugs to our [issues page](https://github.com/aibs-informatics-test-resources/issues).

If you are reporting a bug, please include:

- Your operating system name and version.
- Any details about your local setup that might be helpful in troubleshooting.
- Detailed steps to reproduce the bug, in the form of a [minimal reproducible example](https://stackoverflow.com/help/minimal-reproducible-example).

### Making Changes

Look through the GitHub issues for bugs, features, and other requests. Most issues will have a label that can help you identify the type of issue.  

### Submitting Feedback

The best way to send feedback is to [create an issue](https://github.com/aibs-informatics-test-resources/issues/new) on GitHub.

If you are proposing a feature:

- Explain in detail how it would work.
- Keep the scope as narrow as possible, to make it easier to implement.
- Remember that while contributions are welcome, developer/maintainer time is limited.
